# python-rest-client

# Get started

1. Create an account on https://testnet.delta.exchange/signup

2. Create a new virtualenv and install dependencies

```
virtualenv --python=python3 venv
source venv/bin/activate
pip install -r requirements.txt
```

```python
from delta_rest_client import DeltaRestClient, order_convert_format

delta_client = DeltaRestClient(
  base_url='https://testnet-api.delta.exchange',
  username='',
  password=''
)
product_id = 2
delta_client.get_product(product_id)
order = order_convert_format(7078.5, 10, "buy", product_id)
delta_client.create_order(order) # will create order on testnet

order1 = order_convert_format(7078.5, 10, "buy", product_id)
order2 = order_convert_format(7078.5, 10, "sell", product_id)
orders = [order1, order2]
delta_client.batch_create(product_id, orders)
delta_client.get_orders()
delta_client.get_L2_orders(product_id)
delta_client.get_ticker(product_id)
delta_client.get_wallet()
```
